@@ -274,11 +274,14 @@ def ensure_defaults(options, reqs):
             if key not in options:
                 options[key] = reqs[key]
 
-def command_module(mod, command, options, ending="_command"):
+def command_module(mod, command, options, ending="_command", cli_options=None):
     """Takes a module, uses the command to run that function."""
     function = function_for(mod, command, ending)
     kwargs = determine_kwargs(function)
     ensure_defaults(options, kwargs)
+
+    if "__cli_options" in kwargs.keys():
+        options['__cli_options'] = cli_options
     try:
         function(**options)
     except TypeError as e:
@@ -361,6 +364,8 @@ def parse_and_run_command(argv, mod, default_command=None, exit_on_error=True,
     try:
         command, options = parse(argv)
 
+        cli_options = options.copy()
+
         if extra_options:
             options.update(extra_options)
 
@@ -372,7 +377,7 @@ def parse_and_run_command(argv, mod, default_command=None, exit_on_error=True,
         if command not in available_commands(mod):
             return invalid_command_message(mod, exit_on_error)
 
-        command_module(mod, command, options)
+        command_module(mod, command, options, cli_options=cli_options)
     except ArgumentError, exc:
         print "ERROR: ", exc
         if exit_on_error:
